# lib is called libwebkitgtk-%{libver}.so.%{major}
%define libver  1.0 
%define major	2
%define rev	0

%if %rev
%define oname		WebKit
%else
%define oname		webkit
%endif
%define libname		%mklibname webkitgtk %{libver} %{major}
%define develname	%mklibname webkitgtk %{libver} -d
%define inspectorname	webkit%{libver}-webinspector

%define pango	0
%if %pango
%define fontreq		pango-devel
%define fontback	pango
%else
%define fontreq		fontconfig-devel >= 1.0.0
%define fontback	freetype
%endif

Summary:	Web browser engine
Name:		webkit
Version:	1.1.3
%if %rev
Release:	%mkrel 0.%{rev}.2
%else
Release:	%mkrel 2
%endif
License:	BSD and LGPLv2+
Group:		System/Libraries
# Use the nightlies, don't grab SVN directly: the nightlies are
# MASSIVELY smaller and easier to manage - AdamW 2008/04
%if %rev
Source0:	http://nightly.webkit.org/files/trunk/src/%{oname}-r%{rev}.tar.bz2
%else
Source0:	http://www.webkitgtk.org/%{oname}-%{version}.tar.gz
%endif
Patch0:		webkit-1.1.3-webkitwebhistoryitem.patch
URL:		http://www.webkitgtk.org
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	curl-devel >= 7.11.0
BuildRequires:	flex
BuildRequires:	%{fontreq}
BuildRequires:	gperf
BuildRequires:	libicu-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libpng-devel
BuildRequires:	librsvg-devel >= 2.2.0
BuildRequires:	libstdc++-devel
BuildRequires:	libsoup-devel
BuildRequires:	libtool
BuildRequires:	libxslt-devel
BuildRequires:	pkgconfig
BuildRequires:	gtk2-devel
BuildRequires:	sqlite3-devel
BuildRequires:	xft2-devel
BuildRequires:	libgstreamer-plugins-base-devel
BuildRequires:	gnome-keyring-devel
BuildRoot:	%{_tmppath}/%{name}-%{version}-root

%description
WebKit is an open source web browser engine.

%package -n %{libname}
Summary:	GTK+ port of WebKit web browser engine
Group:		System/Libraries
Obsoletes:	%{mklibname WebKitGdk 0} <= 0-0.30465
Obsoletes:	%{mklibname WebKitGtk 1} <= 0-0.32877
Obsoletes:	%{mklibname webkitgtk 1} <= 1.1.1-3mdv
Obsoletes:	%{mklibname webkitgtk 2} <= 1.1.1-3mdv
# (fhimpe) This provides should probably be removed when major changes
Provides:	%{mklibname webkitgtk 2} = %{version}-%{release}
Provides:	libwebkitgtk = %{version}-%{release}
# Needed for Web Inspector feature to work
Suggests:	%{inspectorname}

%description -n %{libname}
The GTK+ port of WebKit is intended to provide a browser component
primarily for users of the portable GTK+ UI toolkit on platforms like
Linux.

%package -n %{develname}
Summary:	Development files for WebKit GTK+ port
Group:		Development/GNOME and GTK+
Provides:	webkitgtk-devel = %{version}-%{release}
Provides:	libwebkitgtk-devel = %{version}-%{release}
Provides:	%{mklibname webkitgtk -d} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	curl-devel >= 7.11.0
Requires:	fontconfig-devel >= 1.0.0
Requires:	librsvg-devel >= 2.2.0
Requires:	libstdc++-devel
Requires:	xft2-devel >= 2.0.0
Obsoletes:	%{mklibname WebKitGtk -d} <= 0-0.32877
Obsoletes:	%{mklibname webkitgtk -d} < 1.1.1-2mdv

%description -n %{develname}
The GTK+ port of WebKit is intended to provide a browser component
primarily for users of the portable GTK+ UI toolkit on platforms like
Linux. This package contains development headers.

%package gtklauncher
Summary:	WebKit GTK+ example application
Group:		Development/GNOME and GTK+
Conflicts:	%mklibname WebKitGtk 0 <= 0-0.30465

%description gtklauncher
GtkLauncher is an example application for WebKit GTK+.

%package jsc
Summary:	JavaScriptCore shell for WebKit GTK+
Group:		Development/GNOME and GTK+

%description jsc
jsc is a shell for JavaScriptCore, WebKit's JavaScript engine. It
allows you to interact with the JavaScript engine directly.

%package -n %{inspectorname}
Summary:	Data files for WebKit GTK+'s Web Inspector
Group:		System/Libraries
Provides:	webkit-webinspector = %{version}-%{release}
Obsoletes:	webkit-webinspector < 1.1.1-2mdv

%description -n %{inspectorname}
WebKit GTK+ has a feature called the Web Inspector, which allows
detailed analysis of any given page's page source, live DOM hierarchy
and resources. This package contains the data files necessary for Web
Inspector to work.

%prep
%if %rev
%setup -q -n %{oname}-r%{rev}
%else
%setup -q 
%endif
%patch0 -p1 -b .webkitwebhistoryitem

%build
%if %rev
./autogen.sh
%endif
%configure2_5x	--enable-svg-experimental \
              	--with-font-backend=%{fontback} \
		--enable-video \
%ifarch %ix86
		--enable-jit \
%endif
		--enable-gnomekeyring \

%make

%install
rm -rf %{buildroot}
%makeinstall_std
mkdir -p %{buildroot}%{_libdir}/%{name}
install -m 755 Programs/GtkLauncher %{buildroot}%{_libdir}/%{name}

# only useful for testing, should not be installed system-wide.
# reported upstream as 22812 - AdamW 2008/12
rm -rf %{buildroot}%{_libdir}/libtestnetscapeplugin.*

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun	-n %{libname} -p /sbin/ldconfig
%endif

%files -n %{develname}
%defattr(644,root,root,755)
%{_libdir}/lib%{name}-%{libver}.so
%{_libdir}/lib%{name}-%{libver}.la
%{_includedir}/%{name}-%{libver}
%{_libdir}/pkgconfig/%{name}-%{libver}.pc

%files -n %{libname}
%defattr(644,root,root,755)
%{_libdir}/lib%{name}-%{libver}.so.%{major}*

%files gtklauncher
%defattr(0755,root,root)
%{_libdir}/%{name}/GtkLauncher

%files jsc
%defattr(0755,root,root)
%{_bindir}/jsc

%files -n %{inspectorname}
%defattr(0644,root,root)
%{_datadir}/%{name}-%{libver}/webinspector



%changelog
* Thu Jun 04 2009 Rodrigo Gonçalves de Oliveira <rodrigo@mandriva.com> 1.1.3-2mdv2009.1
+ Revision: 382801
- Added patch to fix a bug on webkitwebhistoryitem (bug #50856)

* Mon Mar 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.3-1mdv2009.1
+ Revision: 355568
- Update to new version 1.1.3

* Sun Mar 15 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.1-3mdv2009.1
+ Revision: 355169
- Add some obsoletes so that urpmi handles the update from the wrongly
  named library packages a bit more nicely (bug #47803)

* Sat Mar 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.1-2mdv2009.1
+ Revision: 355044
-Build with gnome-keyring support
-Build with jit (a.k.a. Squirrelfish Extreme) on 32 bit x86
-Fix names of library, devel and webinspector packages so that they
 comply with library policy and can be parallel installable with an
 incompatible new future version
- Don't require exact version of webkit-inspector in library package,
  it breaks update when soname changes. Instead use a suggests (libwebkit
  works without the inspector), and don't use strict version requirement

* Thu Mar 12 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.1-1mdv2009.1
+ Revision: 354351
- Update to new stable version 1.1.1 (new major)
- Remove underlinking patch: not needed anymore

* Sun Feb 15 2009 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.40957.1mdv2009.1
+ Revision: 340397
- buildrequires libsoup-devel
- new release 40957

* Wed Jan 14 2009 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.39872.1mdv2009.1
+ Revision: 329267
- test enabling HTML5 video support (introduces dep on gstreamer)
- drop bison_24.patch (merged upstream)
- new snapshot 39872

* Tue Dec 30 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.39474.1mdv2009.1
+ Revision: 321296
- new snapshot 39474

* Fri Dec 19 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.39370.1mdv2009.1
+ Revision: 316374
- drop include.patch (merged upstream)
- update to rev 39370 (seems much less crash-y...)

* Fri Dec 12 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.39090.1mdv2009.1
+ Revision: 313504
- add include.patch, fixes a build-breaking missing include
- remove an incorrectly installed library
- comment the underlink patch
- add underlink.patch: try and fix underlinking in the unit tests
- add bison_24.patch from upstream #22205 (Bernhard Rosenkraenzer) - fix
  build with bison 2.4
- new snapshot 39090

* Tue Nov 25 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.38707.1mdv2009.1
+ Revision: 306697
- new snapshot 38707

* Fri Nov 07 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.38209.1mdv2009.1
+ Revision: 300836
- package the webinspector stuff into a new subpackage
- new snapshot 38209

* Thu Sep 11 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.36309.1mdv2009.0
+ Revision: 283896
- add some conditionals so i can easily test pango build
- new snapshot 36309

* Sat Sep 06 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.36120.1mdv2009.0
+ Revision: 281774
- new nightly 36120

* Tue Aug 26 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.35933.1mdv2009.0
+ Revision: 276371
- new snapshot 35933

* Wed Aug 13 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.35718.1mdv2009.0
+ Revision: 271515
- new nightly 35718

* Sun Aug 03 2008 Pascal Terjan <pterjan@mandriva.org> 1.0.2-0.35417.1mdv2009.0
+ Revision: 261540
- Update to r35417

* Thu Jul 17 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.2-0.35203.1mdv2009.0
+ Revision: 237829
- disable the underlinking workarounds, they weren't actually helping, let's
  see if it works yet...
- drop icuconfig.patch (fixed in our icu package)
- new snapshot 35203
- seems like we have to disable as-needed as well?
- disable --no-undefined: build breaks due to some internal problem with
  it enabled, looks hard to solve
- add icuconfig.patch to fix call to icu-config in configure
- set version to 1.0.2 (there was a somewhat obscure 1.0.1 'release')
- new snapshot 35177

* Fri Jun 27 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.34824.1mdv2009.0
+ Revision: 229572
- add a subpackage for the newly added javascript shell
- new snapshot 34824

* Fri Jun 20 2008 Götz Waschk <waschk@mandriva.org> 0-0.34503.2mdv2009.0
+ Revision: 227438
- add libwebkitgtk to allow noarch webkit-sharp bindings

* Thu Jun 12 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.34503.1mdv2009.0
+ Revision: 218575
- new snapshot 34503

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed May 21 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.33943.1mdv2009.0
+ Revision: 209799
- correct license (it's dual BSD and LGPL)
- new snapshot

* Mon May 12 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.33029.3mdv2009.0
+ Revision: 206271
- devel package doesn't require libnspr-devel (this was an error in some versions of the plugin patch)

* Mon May 12 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.33029.2mdv2009.0
+ Revision: 206248
- fix the obsoletes
- new snapshot 33029

* Mon May 05 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32877.1mdv2009.0
+ Revision: 201569
- whoops, missed a stray reference to the old (more complex) way of building
- drop the uppercase naming
- improve summaries and descriptions
- clean spec
- drop the qt build (now in upstream qt4)
- new snapshot

* Fri May 02 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32778.1mdv2009.0
+ Revision: 199975
- drop plugin.patch and brace.patch (both merged upstream)
- update snapshot

* Thu May 01 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32698.1mdv2009.0
+ Revision: 199841
- add brace.patch (from upstream SVN, fixes an error that breaks Qt 4.3 build)
- updated plugin patch
- new snapshot

* Fri Apr 25 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32531.2mdv2009.0
+ Revision: 197473
- tweak configure params to try and get 100/100 acid3
- drop all nspr stuff, it was a bogus addition to the plugin patch anyway

* Fri Apr 25 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32531.1mdv2009.0
+ Revision: 197442
- update plugin patch (improved version from upstream)
- update nightly

* Wed Apr 23 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.32416.4mdv2009.0
+ Revision: 196963
- add qt43.patch to fix a bug which caused build with Qt < 4.4 to fail
- updated version of plugin patch
- new snapshot

* Fri Apr 18 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.31893.4mdv2009.0
+ Revision: 195485
- try and fix up the requires_exceptions again...

* Thu Apr 17 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.31893.3mdv2009.0
+ Revision: 195320
- same fix for this patch was needed as for the other one...
- updated version of upstream patch (earlier was incomplete)
- fix a stray reference to a non-existent file in upstream patch
- new version of the plugin patch from upstream bug, hopefully this one will work!

* Thu Apr 17 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.31893.2mdv2009.0
+ Revision: 195033
- drop the patch until i know why it's not working. anyway, it makes acid3 test crash the browser, for some reason
- fix nspr devel requires (autorequires has problems here)
- final plugin patch fixup (but it still doesn't seem to work...will consult with upstream)
- more patch fixing..
- buildrequires libnspr-devel
- ...and one more fix
- more hacking on the patch
- fix changed function name in patch
- oops, bump release
- readd GTK+ plugin patch (31326-plugin.patch), from upstream bug report slightly rediffed

* Tue Apr 15 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.31893.1mdv2009.0
+ Revision: 194083
- new snapshot 31893

* Thu Mar 20 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.31157.1mdv2008.1
+ Revision: 189105
- protect majors in file lists
- move DumpRenderTree to the qt -devel package (aka obey libification policy)
- adjust to new upstream build method for GTK build (using autotools not qmake)
- split GtkLauncher and QtLauncher into separate packages (they're mostly useless demo code and were breaking libification policy)
- correct majors
- use upstream nightly tarball instead of creating one ourselves (apart from anything else it's, like, ten times smaller)
- new snapshot

* Fri Feb 22 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.30465.1mdv2008.1
+ Revision: 173823
- drop Implement-plugin-support-in-GTK-backend.patch (merged upstream)
- new snapshot 30465

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild

* Fri Feb 08 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0-0.30005.1mdv2008.1
+ Revision: 163896
- Patch0: add support for external plugins (flashplayer and so forth). At the current stage this supports only GTK version of WebKit. Patch should be merged into upstream svn quite soon. For more info please see http://bugs.webkit.org/show_bug.cgi?id=14750
- fix buildroot

* Wed Jan 30 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.29866.1mdv2008.1
+ Revision: 160152
- new snapshot 29866

* Sat Jan 05 2008 Adam Williamson <awilliamson@mandriva.org> 0-0.29184.1mdv2008.1
+ Revision: 145662
- 29013 doesn't build, go to current (29184)
- new snapshot 29013 (required by latest midori)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 13 2007 Adam Williamson <awilliamson@mandriva.org> 0-0.28663.1mdv2008.1
+ Revision: 119551
- package a newly-introduced file
- new SVN snapshot 28663

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix summary

* Wed Nov 21 2007 Thierry Vignaud <tvignaud@mandriva.com> 0-0.26100.2mdv2008.1
+ Revision: 111025
- rebuild for new libicu

* Mon Oct 08 2007 Pascal Terjan <pterjan@mandriva.org> 0-0.26100.1mdv2008.0
+ Revision: 95684
- Obsoletes libWebKitGdk0
- Update to revision 26100
- s/Gdk/Gtk/g; s/gdk/gtk/
- DumpRenderTree changed location

* Sun Sep 02 2007 Pascal Terjan <pterjan@mandriva.org> 0-0.25144.3mdv2008.0
+ Revision: 78087
- Add some BuildRequires for the Qt version
- Oops fix the Provides

* Sat Sep 01 2007 Pascal Terjan <pterjan@mandriva.org> 0-0.25144.2mdv2008.0
+ Revision: 77413
- Add some provides on -devel packages

* Sat Sep 01 2007 Pascal Terjan <pterjan@mandriva.org> 0-0.25144.1mdv2008.0
+ Revision: 77392
- Fix group
- Put QtWebKit.pc in a place where pkgconfig will find it
- Import webkit



* Fri Aug 31 2007 Pascal Terajn <pterjan@mandriva.org> 0-0.25144.1mdv2008.0
- Initial Mandriva package (some inspiration from Debian)
